
print <<'EOF';
# Setup the language environment
if [ -f ${HOME}/.xcyrillic ]; then . ${HOME}/.xcyrillic; fi
EOF




